==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/ProxyStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ProxyStatusFluentImpl<A extends io.fabric8.openshift.api.model.ProxyStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ProxyStatusFluent<A>{
  public ProxyStatusFluentImpl() {
  }
  public ProxyStatusFluentImpl(io.fabric8.openshift.api.model.ProxyStatus instance) {
    this.withHttpProxy(instance.getHttpProxy()); 
    this.withHttpsProxy(instance.getHttpsProxy()); 
    this.withNoProxy(instance.getNoProxy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String httpProxy;
  private java.lang.String httpsProxy;
  private java.lang.String noProxy;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHttpProxy() {
    return this.httpProxy;
  }
  public A withHttpProxy(java.lang.String httpProxy) {
    this.httpProxy=httpProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpProxy() {
    return this.httpProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpProxy(java.lang.String arg0) {
    return (A)withHttpProxy(new String(arg0));
  }
  public java.lang.String getHttpsProxy() {
    return this.httpsProxy;
  }
  public A withHttpsProxy(java.lang.String httpsProxy) {
    this.httpsProxy=httpsProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpsProxy() {
    return this.httpsProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpsProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpsProxy(java.lang.String arg0) {
    return (A)withHttpsProxy(new String(arg0));
  }
  public java.lang.String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(java.lang.String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public java.lang.Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  
  /**
   * Method is deprecated. use withNoProxy instead.
   */
  @java.lang.Deprecated
  public A withNewNoProxy(java.lang.String arg0) {
    return (A)withNoProxy(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProxyStatusFluentImpl that = (ProxyStatusFluentImpl) o;
    if (httpProxy != null ? !httpProxy.equals(that.httpProxy) :that.httpProxy != null) return false;
    if (httpsProxy != null ? !httpsProxy.equals(that.httpsProxy) :that.httpsProxy != null) return false;
    if (noProxy != null ? !noProxy.equals(that.noProxy) :that.noProxy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpProxy,  httpsProxy,  noProxy,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ProxyStatusFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ProxyStatusFluentImpl<A extends io.fabric8.openshift.api.model.ProxyStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ProxyStatusFluent<A>{
  public ProxyStatusFluentImpl() {
  }
  public ProxyStatusFluentImpl(io.fabric8.openshift.api.model.ProxyStatus instance) {
    this.withHttpProxy(instance.getHttpProxy()); 
    this.withHttpsProxy(instance.getHttpsProxy()); 
    this.withNoProxy(instance.getNoProxy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String httpProxy;
  private java.lang.String httpsProxy;
  private java.lang.String noProxy;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHttpProxy() {
    return this.httpProxy;
  }
  public A withHttpProxy(java.lang.String httpProxy) {
    this.httpProxy=httpProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpProxy() {
    return this.httpProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpProxy(java.lang.String arg0) {
    return (A)withHttpProxy(new String(arg0));
  }
  public java.lang.String getHttpsProxy() {
    return this.httpsProxy;
  }
  public A withHttpsProxy(java.lang.String httpsProxy) {
    this.httpsProxy=httpsProxy; return (A) this;
  }
  public java.lang.Boolean hasHttpsProxy() {
    return this.httpsProxy != null;
  }
  
  /**
   * Method is deprecated. use withHttpsProxy instead.
   */
  @java.lang.Deprecated
  public A withNewHttpsProxy(java.lang.String arg0) {
    return (A)withHttpsProxy(new String(arg0));
  }
  public java.lang.String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(java.lang.String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public java.lang.Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  
  /**
   * Method is deprecated. use withNoProxy instead.
   */
  @java.lang.Deprecated
  public A withNewNoProxy(java.lang.String arg0) {
    return (A)withNoProxy(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProxyStatusFluentImpl that = (ProxyStatusFluentImpl) o;
    if (httpProxy != null ? !httpProxy.equals(that.httpProxy) :that.httpProxy != null) return false;
    if (httpsProxy != null ? !httpsProxy.equals(that.httpsProxy) :that.httpsProxy != null) return false;
    if (noProxy != null ? !noProxy.equals(that.noProxy) :that.noProxy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpProxy,  httpsProxy,  noProxy,  additionalProperties,  super.hashCode());
  }
  
}
